"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Fetcher = void 0;
var Fetcher = {
  get: get,
  post: post,
  put: put,
  patch: patch,
  "delete": _delete
};
exports.Fetcher = Fetcher;

function get(url) {
  var requestOptions = {
    method: 'GET'
  };
  return fetch(url, requestOptions).then(handleResponse);
}

function post(url, body) {
  var requestOptions = {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(body)
  };
  return fetch(url, requestOptions).then(handleResponse);
}

function put(url, body) {
  var requestOptions = {
    method: 'PUT',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(body)
  };
  return fetch(url, requestOptions).then(handleResponse);
}

function patch(url, body) {
  var requestOptions = {
    method: 'PATCH',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(body)
  };
  return fetch(url, requestOptions).then(handleResponse);
} // prefixed with underscored because delete is a reserved word in javascript


function _delete(url) {
  var requestOptions = {
    method: 'DELETE'
  };
  return fetch(url, requestOptions).then(handleResponse);
} // helper functions


function handleResponse(response) {
  return response.text().then(function (text) {
    var data = text && JSON.parse(text);

    if (!response.ok) {
      var error = data && data.message || response.statusText;
      return Promise.reject(error);
    }

    return data;
  });
}